.. _app_migrating:

=======================================
Migrating applications between releases
=======================================

This document describes how a developer of murano application can update
existing packages to make them synchronized with all implemented features
and requirements.

.. toctree::
   :maxdepth: 1

   app_migrating/app_migrate_to_juno
   app_migrating/app_migrate_to_kilo
   app_migrating/app_migrate_to_liberty
   app_migrating/app_migrate_to_newton
